/* dsge_main.g
**
** This file runs a batch estimation  
**
*/
new;
closeall;
cls;
library user, pgraph;

dlibrary -a PszTgSen,PsdTgSen;

format /mat /on /mb1 /ros 16,8;
outwidth 256;


#include dsge_spec.g;
#include dsge_para.src;
#include dsge_mod.src;
#include dsge_lh.src;
#include dsge_procs.src;

datasel_vec = 1 | 2 | 3 | 4 | 5 | 6;
datasel_n   = rows(datasel_vec);

datasel_ind = 1;
do until datasel_ind > datasel_n;

      datasel = datasel_vec[datasel_ind];

      /************************************************
      *  DATASEL
      *
      *  0 US data
      *  1-6 Simulated data
      *
      ************************************************/

      if datasel == 1;
         dataselstr = "tauh029tauk035chi036";
      elseif datasel == 2;
         dataselstr = "tauh022tauk035chi036";
      elseif datasel == 3 ;
         dataselstr = "tauh029tauk047chi036";
      elseif datasel == 4;
         dataselstr = "tauh029tauk035chi050";
      elseif datasel == 5;
         dataselstr = "tauh0229tauk0443chi0224";
      elseif datasel == 6;
         dataselstr = "tauh0269tauk0327chi0417";
      elseif datasel == 0;
         dataselstr = "us";
      endif;

      #include path_spec.g;
      #include loaddata.g;
 
      /******************************/
      /* Compute the Posterior Mode */
      /******************************/
      
      #include dsge_pm.g;

      /******************************/
      /*    Compute the Hessian     */
      /******************************/

      #include dsge_hess.g;
      
      /******************************/
      /* Run RWM Algorithm          */
      /******************************/

      mhrun   = "1";
      nblocks = 10;
      nsim    = 10000;
      cc0     = 1;
      cc      = 0.6;  
      appendmode = 0;

      #include dsge_mh.g;

      /******************************/
      /* Compute Posterior Mom      */
      /******************************/

      mhrun  = "1";
      nburn  = 1001;        
      hpdprob     = 0.90;
      block_size  = 10000;

      #include paramom1.g;

      /******************************/
      /* Compute Steady States      */
      /******************************/

      mhrun  = "1";
      nblock = 10000;    /* block size */
      nuse   = 1;        /* use every nuse observation */

      #include dsge_stst.g;

      mhrun   = "1";
      nburn   = 1;    /* initial draws to be discarded */
      hpdprob = 0.90 ;

      #include dsge_ststpmom1.g;

      /******************************/
      /* Conduct Policy Predictions */
      /******************************/

      mhrun  = "1";
      nblock = 10000;    /* block size */
      nuse   = 1;        /* use every nuse observation */

      if datasel == 1;
         /* Benchmark Specification */

         taxind_vec = 1|2|3|4|5|6;
         taxind_n   = rows(taxind_vec);
         taxind_ind = 1;

         do until taxind_ind > taxind_n;
            taxind = taxind_vec[taxind_ind];
            
            #include dsge_ststpctpred.g;
            
            nburn   = 1;    
            hpdprob = 0.90;
            nblock  = 10000;

            #include dsge_ststpmom2.g;

            taxind_ind = taxind_ind+1;
         endo;

      endif;

      datasel_ind = datasel_ind+1;
      
endo;


