
/* filename:    dsge_stst.g
** description: posterior mode batch
** created:     08/18/2006
*/

/********************************************************
* House cleaning and set defaults
********************************************************/

/** Global defaults **/
__output = 1;       /** 1 for verbose of CSMIN**/
__graph  = 1;       /** 1 for graph mode **/
_verbose = 2;       /** 0 for silence, 1 for compact, 2 for detailed**/
_fcmptol = 1E-10;

/********************************************************************
* Load Parameter Draws from MH Output
********************************************************************/

lpath  = parapath $+ "\\mhrun" $+ mhrun;
opath  = resupath $+ "\\mhrun" $+ mhrun;
chkdir = chk_dir(opath);

lpara  = lpath $+ "\\pa";

open fhpara = ^lpara for read;

/* save steady states: capital, hours, consumption, output, rsmall, wage bill, 
** capital rental, government spending
*/

para    = pmsv(msel);
nstst   = 8;

/** Initialize Output files **/
ostst = opath $+ "\\stst";           
create fhstst = ^ostst with STST, nstst, 8;  

/** Initialization **/
eofloop = 0;
loopct  = 1;

"";
"Calculating steady states...";
"----------------------------";

do until eofloop;

   "";
   "Block           " ftos(loopct,"%*.*lf",6,0);

   /** Read blocks of size nblock **/
   parasim = readr( fhpara, nblock );
   nread   = rows( parasim );

   /** use every nuse-th draw **/
   indseq  = seqa(1,1,nread);
   indseq  = indseq % nuse;
   indseq  = indseq .NE 0;

   parasim = delif(parasim,indseq);
   nread   = rows(parasim);

   if ismiss(parasim) == 0;
 
      ststsim = zeros(nread,nstst);

      j = 1;
      do until j > nread;
      
         para = parasim[j,.]';
         {sst, valid} = dsgess(para,msel);
         /* steady states: sst = hst | rst | wst | yst | kst | gst | cst | rsmallst;
         ** re-order: capital, hours, consumption, output, rsmall, wage bill, 
         ** capital rental, government spending
         */
         ststsim[j,.] = sst[5] ~ sst[1]    ~ sst[7]        ~ sst[4] 
                      ~ sst[8] ~ sst[1]*sst[3] ~ sst[5]*sst[8] ~ sst[6];

         if fmod(j,nread/10)==0; ".";; pause(1e-20);endif;
         j = j+1;

      endo;

      /** write Output **/
      wr = writer(fhstst,ststsim);

   endif;      /* for ismiss */

   "";
   "Draws Processed " ftos(rows(ststsim),"%*.*lf",6,0);
   "";

   loopct = loopct + 1;
   eofloop = eof(fhpara);

endo;

closeall fhpara, fhstst;

