/******************************************************************************
* DSGE_STSTPMOM.G
* computes posterior mean and std and CI based on output of posterior simulator
* steady states
******************************************************************************/

/** Global defaults **/
  _verbose = 1;           /** 1 for verbose **/

/********************************************************************
* Load Parameter Draws from MH Output
********************************************************************/

if taxind == 1;
   tax_str = "tauh029tauk035chi036pct";
elseif taxind == 2;
   tax_str = "tauh022tauk035chi036pct";
elseif taxind == 3;
   tax_str = "tauh029tauk047chi036pct";
elseif taxind == 4;
   tax_str = "tauh029tauk035chi050pct";
elseif taxind == 5;
   tax_str = "tauh0229tauk0443chi0224pct";
elseif taxind == 6;
   tax_str = "tauh0269tauk0327chi0417pct";
endif;

lpath  = resupath $+ "\\mhrun" $+ mhrun;
opath  = resupath $+ "\\mhrun" $+ mhrun;

ldraw  = lpath $+ "\\stst" $+ tax_str ;
odraws = opath $+ "\\ststs" $+ tax_str ;      

open fhdraw = ^ldraw for read;

drawrow = readr(fhdraw, nburn);
drawdim = cols(drawrow);
drawrow = seekr(fhdraw, nburn);

/** start log file **/
outstr = resupath $+ "\\" $+ tax_str $+ ftos(timedt,"%*.*lf",1,0) $+ "ststpmom2.log";
output file = ^outstr reset;

/********************************************************************
* Part 1: Compute the mean of x(i) and x^2(i)
********************************************************************/
drawmean   = zeros(1,drawdim);
drawsqmean = zeros(1,drawdim);
drawcross  = zeros(drawdim,drawdim);

eofloop = 0;
ndraws  = 0;

if _verbose;
   "";
   "=============================================";
   "Steady States                                ";
   "";
   "Model            " $lmodel;
   "Data set         " $dataselstr;
   "Prior            " $lprior;
   "Subsample        " $subTstr;
   "MHrun Index      " $mhrun;
   "Coverage         " hpdprob;
   "=============================================";
   "";
   "Part 1: Mean and Standard Deviation";
endif;

do until eofloop;

   drawblock  = readr(fhdraw,nblock);

   drawmean   = drawmean   + sumc(drawblock)';
   drawsqmean = drawsqmean + sumc(drawblock^2)';
   drawcross  = drawcross  + drawblock'*drawblock;

   ndraws = ndraws + rows(drawblock);

   if _verbose;
      ".";;pause(1e-20);
   endif;

   eofloop = eof(fhdraw);

endo;

drawmean   = drawmean/ndraws;
drawsqmean = drawsqmean/ndraws;
drawstdd   = sqrt(drawsqmean - (drawmean)^2);
drawcov    = drawcross/ndraws - drawmean'*drawmean;

/* save steady states: capital, hours, consumption, output, rsmall, wage bill, 
** capital rental, government spending
*/

draw_names = { Hst Cst Yst } ; 

if _verbose;

   /** Report Posterior Mean and stderror **/
   "";
   outmat = ("Parameter"  $~ "Mean" $~ "Stdd") $|
            ( (draw_names') $~ ftocv( (drawmean' ~ real(drawstdd)'),4,4) );

   $outmat;

endif;


/********************************************************************
* Part 2: HPD Interval
********************************************************************/
drawrow = seekr( fhdraw, nburn);
drawci  = zeros( 2,drawdim);

if _verbose;
   "";
   "Part 2: HPD Interval";
endif;

j = 1;
do until j > drawdim;

   /** Read only the j'th column **/
   drawrow   = seekr(fhdraw,nburn);
   drawblock = readr(fhdraw,1);

   drawcol = drawblock[1,j];
   eofloop = 0;
   ndraws  = 1;

   do until eofloop;

      drawblock = readr(fhdraw,nblock);
      drawcol   = drawcol | drawblock[.,j];
      ndraws    = ndraws + rows(drawblock);
      eofloop   = eof(fhdraw);

   endo;

   if _verbose;".";;pause(1e-20);endif;

   drawci[.,j] = hpdint(drawcol,hpdprob);
   j = j+1;

endo;
clear drawcol;

/** Report **/
if _verbose;
   "";"";

   outmat = ("Parameter"  $~ "Mean" $~ "Stdd" $~ "CI(LOW)" $~ "CI(HIGH)") $|
            ( (draw_names') $~ ftocv( (drawmean' ~ real(drawstdd)' ~ drawci'),4,3) );

   $outmat;

   "";
endif;

create fhdraws = ^odraws with DRAWSUM, drawdim, 8;
wr = writer(fhdraws, real(drawmean | drawstdd | drawcov | drawci) );
closeall fhdraws;

/** close log file **/
output file = ^outstr off;
