
/* filename:    dsge_ststpred.g
** description: posterior mode batch
** created:     08/18/2006
*/

new;
/** set seed **/
/** rndseed 1234; **/

/********************************************************
* House cleaning and set defaults
********************************************************/
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

/** Global defaults **/
__output = 1;       /** 1 for verbose of CSMIN**/
__graph  = 1;       /** 1 for graph mode **/
_verbose = 2;       /** 0 for silence, 1 for compact, 2 for detailed**/
_fcmptol = 1E-10;

#include dsge_spec.g;
#include path_spec.g;
#include dsge_para.src;
#include dsge_mod.src;

/********************************************************************
* Load Parameter Draws from MH Output
********************************************************************/
mhrun  = "1";
nblock = 10000;    /* block size */
nuse   = 1;        /* use every nuse observation */
taxind = 2;

if taxind == 1;
   tax_str = "";
elseif taxind == 2;
   tax_str = "tauh022tauk035chi036pct";
   tauH_fix = 0.22;
   tauK_fix = 0.35;
   chi_fix  = 0.36;
elseif taxind == 3;
   tax_str = "tauh029tauk047chi036pct";
   tauH_fix = 0.29;
   tauK_fix = 0.47;
   chi_fix  = 0.36;
elseif taxind == 4;
   tax_str = "tauh029tauk035chi050pct";
   tauH_fix = 0.29;
   tauK_fix = 0.35;
   chi_fix  = 0.50;
elseif taxind == 5;
   tax_str = "tauh0229tauk0443chi0224pct";
   tauH_fix = 0.229;
   tauK_fix = 0.443;
   chi_fix  = 0.224;
elseif taxind == 6;
   tax_str = "tauh0269tauk0327chi0417pct";
   tauH_fix = 0.269;
   tauK_fix = 0.327;
   chi_fix  = 0.417;
endif;

lpath  = parapath $+ "\\mhrun" $+ mhrun;
opath  = resupath $+ "\\mhrun" $+ mhrun;
chkdir = chk_dir(opath);

lpara  = lpath $+ "\\pa";

open fhpara = ^lpara for read;

/* steady states: capital, hours, consumption, output, rsmall, wage bill, 
** capital rental, government spending
** save: hours, consumption, output
*/

para    = pmsv(msel);
nstst   = 3;

/** Initialize Output files **/

ostst   = opath $+ "\\ststperturb" $+ tax_str;           
oparacf = lpath $+ "\\pacfperturb"   $+ tax_str;           

create fhstst = ^ostst with STST, nstst, 8;  
create fhparacf = ^oparacf with PARACF, rows(para), 8;

/** Initialization **/
eofloop = 0;
loopct  = 1;

if _verbose;
   "";
   "Calculating steady states...";
   "----------------------------";
endif;

do until eofloop;

   if _verbose;
      "";
      "Block           " ftos(loopct,"%*.*lf",6,0);
   endif;

   /** Read blocks of size nblock **/
   parasim = readr( fhpara, nblock );
   nread   = rows( parasim );

   /** use every nuse-th draw **/
   indseq  = seqa(1,1,nread);
   indseq  = indseq % nuse;
   indseq  = indseq .NE 0;

   parasim = delif(parasim,indseq);
   nread   = rows(parasim);

if ismiss(parasim) == 0;
 
   ststsim = zeros(nread,nstst);
   parasimcf = parasim;

   j = 1;
   do until j > nread;
   
      para = parasim[j,.]';
      
      /* baseline */
      {sstbaseline, valid} = dsgess(para,msel);
      
      /* counterfactual */
      if taxind > 0;
         para[6] = tauH_fix;
         para[7] = tauK_fix;
         para[8] = chi_fix;
         
         if (taxind == 4) or (taxind == 2);
         /* rA */  para[2]  = maxc( 0.001 | (para[2] + 0.09*rndn(1,1) )); 
         /* nu */  para[4]  = maxc( 0.001 | (para[4] + 0.09*rndn(1,1) )); 
         /* A0 */  para[9]  = para[9]+0.002*rndn(1,1); 
         /* B0 */  para[10] = para[10]+0.003*rndn(1,1); 
         elseif taxind == 5;
         /* 1960 Policy */
         /* rA */   para[2]  = maxc( 0.01 | (para[2] -0.282 + 0.197*rndn(1,1)) ); 
         /* nu */   para[4]  = maxc( 0.01 | (para[4] -1.484 + 0.189*rndn(1,1)) ); 
         /* A0 */   para[9]  = para[9]-0.045+0.004*rndn(1,1);  
         /* B0 */   para[10] = para[10]-0.01+0.007*rndn(1,1); 
         elseif taxind == 6;
         /* 2004 Policy */
         /* rA */   para[2]  = maxc( 0.01 | (para[2] -0.003 + 0.07*rndn(1,1)) ); 
         /* nu */   para[4]  = maxc( 0.01 | (para[4] +0.229 + 0.067*rndn(1,1)) ); 
         /* A0 */   para[9]  = para[9]  +0.002*rndn(1,1);  
         /* B0 */   para[10] = para[10] +0.004 +0.002*rndn(1,1); 
         endif;

         parasimcf[j,2 4 9 10] = para[2]~para[4]~para[9]~para[10];
 
      endif; 
      {sstcounterfactual, valid} = dsgess(para,msel);
      /* steady states: sst = hst | rst | wst | yst | kst | gst | cst | rsmallst;
      ** re-order: hours, consumption, output
      */
     
      /* compute changes
      */
      sst = 100*(ln(sstcounterfactual)-ln(sstbaseline));
     
      ststsim[j,.] = sst[1] ~ sst[7] ~ sst[4]; 
                   
      if _verbose;
         if fmod(j,nread/10)==0; ".";; pause(1e-20);endif;
      endif;
      j = j+1;
   endo;

 /** write Output **/
 wr = writer(fhstst,ststsim);
 wr = writer(fhparacf,parasimcf);

endif;      /* for ismiss */


   if _verbose;
      "";
      "Draws Processed " ftos(rows(ststsim),"%*.*lf",6,0);
      "";
   endif;

   loopct = loopct + 1;
   eofloop = eof(fhpara);

endo;

closeall fhpara, fhstst, fhparacf;

end;
