/* filename:    paratab-post1.g
** description: generates a LaTeX Table  
*/

new;
closeall;
library user, pgraph;
cls;
outwidth 128;

#include dsge_spec.g;
#include path_spec.g;
#include dsge_para.src;

para  = pmsv(msel);
npara = rows(para);
{para,para_names} = psel(para,msel);


/******************************************************************
**         Load Parameter Draws from MH Output
*/

/* Specify input files - you have to edit the inputfile_str
** to read the desired estimates
** filename: lmodel + lprior + dataselstr + subTstr + pas
*/
inputfile_str = "\\tauh029tauk035chi036m12t1p1\\results\\mhrun1\\stststauh022tauk035chi036pct" $|
                "\\tauh029tauk035chi036m12t1p1\\results\\mhrun1\\stststauh029tauk047chi036pct" $|
                "\\tauh029tauk035chi036m12t1p1\\results\\mhrun1\\stststauh029tauk035chi050pct" $|
                "\\tauh029tauk035chi036m12t1p1\\results\\mhrun1\\stststauh0229tauk0443chi0224pct" $|
                "\\tauh029tauk035chi036m12t1p1\\results\\mhrun1\\stststauh0269tauk0327chi0417pct"
                ;
             
/* Specify row names for table
*/
row_name =  "$H$    "
         $| "$C$    "
         $| "$Y$    "
         ;

inputfile_n = rows(inputfile_str);

npara = rows(row_name);

post_mean = zeros(npara,inputfile_n);
post_std  = zeros(npara,inputfile_n);
post_ci   = zeros(npara,inputfile_n*2);

true_values = ( 6.06 ~ -0.23 ~ -5.45 ~ 9.44 ~ -0.21 ) |
              ( 7.33 ~ -2.73 ~  3.04 ~ 1.73 ~  3.86 ) |
              ( 3.44 ~ -2.89 ~ -2.19 ~ 2.57 ~  0.81 ) ;


/* read the input files
*/
inputfile_ind = 1;

do until inputfile_ind > inputfile_n;

   lparas = workpath $+ inputfile_str[inputfile_ind];
   open fhparas = ^lparas for read;
   
   post_mean[.,inputfile_ind] = readr(fhparas,1)';
   post_std[.,inputfile_ind]  = readr(fhparas,1)';

   drawrow = seekr(fhparas,npara+3);
   post_ci[.,2*(inputfile_ind-1)+1:2*inputfile_ind] = readr(fhparas,2)';

   inputfile_ind = inputfile_ind+1;
   
   closeall fhparas;
   
endo;



/* Create table
*/
para_ind = 1;
do until para_ind > npara;

   tablerow = row_name[para_ind] $+ " & ``True'' ";

   inputfile_ind = 1;
   
   do until inputfile_ind > inputfile_n;

      tablerow = tablerow $+ " & " $+ ftos(true_values[para_ind,inputfile_ind],"%*.*lf",5,2);                 
      inputfile_ind = inputfile_ind+1;
      
   endo;
   tablerow  = tablerow  $+ "\\\\";
   
   $tablerow;

   tablerow = " & 90\\% Intv.  ";   
   inputfile_ind = 1;
   
   do until inputfile_ind > inputfile_n;

      tablerow = tablerow   $+ " & [" $+ ftos(post_ci[para_ind,2*(inputfile_ind-1)+1],"%*.*lf",5,2)
                 $+ ", "  $+ ftos(post_ci[para_ind,2*(inputfile_ind)],"%*.*lf",5,2) $+ "]"; 

      inputfile_ind = inputfile_ind+1;
      
   endo;
   tablerow  = tablerow  $+ "\\\\";
   
   $tablerow;

   tablerow = " & Score  ";   
   inputfile_ind = 1;
   
   do until inputfile_ind > inputfile_n;

      score =  cdfn( -abs(true_values[para_ind,inputfile_ind]
                 - post_mean[para_ind,inputfile_ind])
                   / post_std[para_ind,inputfile_ind]); /* / post_std[para_ind,inputfile_ind];*/

      tablerow = tablerow $+ " & " $+ ftos(score,"%*.*lE",5,1);

      inputfile_ind = inputfile_ind+1;
      
   endo;
   tablerow  = tablerow  $+ "\\\\";
   
   $tablerow;

   para_ind = para_ind+1;

endo;
