/***************************************************************/
/*                                                             */
/*     VAR analysis: compute marginal data density             */
/*                                                             */
/***************************************************************/

new;
closeall; 
library pgraph;
cls;

#include vm_spec.g; 
#include path_spec.g;

/******************************************************** 
* Import data series to determine length of sample      *
********************************************************/

#include loaddata.g;
/** number of actual observations
**/  
nobs    =   rows(YY)-nlags_;  


/******************************************************** 
* Load Y and XX matrices for dummy and actual observations  
********************************************************/

/** check if you have run vm_dummy.g first 
**/

odumobs =   priopath $+ "\\dumobs" $+ ".dat";

if not(exist(odumobs));
    "";
    "Please run vm_dummy.g first";
    "";
    end;
endif;

/** open output generated by vm_dummy.g 
**  dummy obs:  Y0 X0
**  actual obs: Y1 X1
**/

open odumobs = ^odumobs;
obs = readr(odumobs,1+(nlags_+w+1)*nvar_+nobs);  
closeall odumobs;


/** initialize matrices containing both dummy observations ("XXstar" and "YYstar"") 
**  and actual observations (XX and YY). 
**/

n_dummy     =   1+(nlags_+w+1)*nvar_;
col_obs     =   nvar_+nlags_*nvar_+1;

XXstar      =   obs[1:n_dummy,1+nvar_:col_obs];
YYstar      =   obs[1:n_dummy,1:nvar_];

XX          =   obs[n_dummy+1:n_dummy+nobs,1+nvar_:col_obs];
YY          =   obs[n_dummy+1:n_dummy+nobs,1:nvar_];

/* Defining constants 
*/ 
k       = 1 + nvar_*nlags_;             /* number of parameters per equation  */
Tstar   = rows(YYstar);                 /* # of dummy obs                     */
T1      = rows(YY);                     /* # of actual obs                    */

/** Compute the log marginal data density for the VAR model 
**/ 

/* OLS estimator for dummy observations 
*/

Phi0 = inv(XXstar'*XXstar)*XXstar'*YYstar; 
S0   = (YYstar-XXstar*Phi0)'(YYstar-XXstar*Phi0); 

/* OLS estimator for both dummy and actual observations 
*/

XXtot = XXstar|XX;
YYtot = YYstar|YY;
Phi1  = inv(XXtot'*XXtot)*XXtot'*YYtot; 
S1    = (YYtot-XXtot*Phi1)'*(YYtot-XXtot*Phi1); 

/* compute constants for integrals
*/

i=1;  
gamdum=0; 
gamt=0; 

do until i>nvar_; 
   gamdum=gamdum+lngam(0.5*(Tstar-k+1-i)); 
   gamt=gamt+lngam(0.5*(Tstar+T1-k+1-i)); 
   i=i+1; 
endo; 

/* dummy observation
*/
lmdum = -nvar_*(Tstar-k)*0.5*ln(pi)-(nvar_/2)*ln(abs(det(XXstar'XXstar)))
        -(Tstar-k)*0.5*ln(abs(det(S0)))+nvar_*(nvar_-1)*0.25*ln(pi)+gamdum;
/* dummy and actual observations
*/   
lmdt  = -nvar_*(Tstar+T1-k)*0.5*ln(pi)-(nvar_/2)*ln(abs(det(XXtot'XXtot)))
        -(Tstar+T1-k)*0.5*ln(abs(det(S1)))+nvar_*(nvar_-1)*0.25*ln(pi)+gamt;  

lmd=lmdt-lmdum; 

/** start log file **/
outstr = resupath $+ "\\mdd.log"; 
output file = ^outstr reset;


"";
    "===================================";
    "Model            " $lmodel;
    "Data set         " $dataselstr;
    "Prior            " $lprior;
    "Subsample        " $subTstr;
    "";
    "===================================";
    "";
    
    "";
    "Log-marginal Density =" lmd; 


"";
